@@ -8,6 +8,14 @@ BASE_DATA_DIR = os.path.join(BASE_DIR, 'data', 'sample')
 
 
 def load_dem(area_name=None):
+    """加载海拔高度样例数据
+
+    参数:
+        area_name (str, 可选): 区域名称, 若为None则取全国. 默认为 None.
+
+    返回值:
+        tuple: (lons, lats, data)
+    """
     SUB_AREA = {'京津冀': np.s_[95:149, 207:259]}
     ds = nc.Dataset(os.path.join(BASE_DATA_DIR, 'china_dem.nc'))
     lon = ds.variables['lon'][:]
